"""
add_seconds template filter module
"""

import datetime

from django import template
from django.utils.dateparse import (
    parse_date as _parse_date,
    parse_datetime as _parse_datetime,
    parse_time as _parse_time,
)


register = template.Library()


@register.filter
def parse_date(value):
    """
    Filter parsing date
    and returning a date value
    """
    if isinstance(value, str):
        return _parse_date(value)


@register.filter
def parse_time(value):
    """
    Filter parsing time
    and returning a time value
    """
    if isinstance(value, str):
        return _parse_time(value)


@register.filter
def parse_datetime(value):
    """
    Filter parsing datetime
    and returning a datetime value
    """
    if isinstance(value, str):
        return _parse_datetime(value)


@register.filter
def addseconds(value, arg):
    """
    Filter adding seconds to the datetime parameter.

    If the `value` parameter is not a datetime,
    tries to convert to it. Integer as a unixtime,
    string as a string timestamp.

    If the `arg` is a string, converts
    it to the numeric.
    """

    if not isinstance(value, datetime.datetime):
        if isinstance(value, datetime.date):
            value = datetime.datetime.combine(value, datetime.time(0))
        elif isinstance(value, (int, float)):
            value = datetime.datetime.fromtimestamp(value)
        elif isinstance(value, str):
            value = _parse_datetime(value)
    if not isinstance(value, datetime.datetime):
        return
    if isinstance(arg, str):
        try:
            arg = float(arg)
        except ValueError:
            return
    if not isinstance(arg, (int, float)):
        return

    return value + datetime.timedelta(0, arg)



#!/usr/bin/python

"""
A setup module.
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

setup(
    name='django-addseconds',

    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version='0.0.2b1',

    description='The Django-AddSeconds package provides template filters for datetime manipulations',
    long_description='''
Django-AddSeconds
=================

The package provides template filters for datetime manipulations.
See details at the home page: https://github.com/nnseva/django-addseconds
''',

    # The project's main homepage.
    url='https://github.com/nnseva/django-addseconds',

    # Author details
    author='Vsevolod Novikov',
    author_email='nnseva@gmail.com',

    zip_safe=False,
    platforms = "any",

    # Choose your license
    license='LGPL',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        #'Development Status :: 3 - Alpha',
        'Development Status :: 4 - Beta',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries',

        'Environment :: Web Environment',

        'Framework :: Django',
        'Framework :: Django :: 2.0',
        'Framework :: Django :: 2.1',
        'Framework :: Django :: 3.0',
        'Framework :: Django :: 3.1',
        'Framework :: Django :: 3.2',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: GNU Library or Lesser General Public License (LGPL)',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],

    # What does your project relate to?
    keywords='django templatetags datetime',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=find_packages(exclude=['dev', 'dev.*']),

    install_requires=[
        'django',
    ],
)
